<?php

namespace Alum\Alum\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Alum\Alum\Http\Requests\WebAlumnusAdminRequest;
use Alum\Alum\Interfaces\WebAlumnusRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class WebAlumnusAdminController extends AdminController
{
    /**
     * Initialize web_alumnus controller.
     *
     * @param type WebAlumnusRepositoryInterface $web_alumnus
     *
     * @return type
     */
    public function __construct(WebAlumnusRepositoryInterface $web_alumnus)
    {
        $this->model = $web_alumnus;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(WebAlumnusAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('alum.web_alumnus.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('alum::web_alumnus.names').' :: ');

        return $this->theme->of('alum::admin.web_alumnus.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(WebAlumnusAdminRequest $request, $id)
    {
        $web_alumnus = $this->model->find($id);

        if (empty($web_alumnus)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('alum::admin.web_alumnus.new');
        }

        if ($request->wantsJson()) {
            return $web_alumnus;
        }

        Former::populate($web_alumnus);

        return view('alum::admin.web_alumnus.show', compact('web_alumnus'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(WebAlumnusAdminRequest $request)
    {
        $web_alumnus = $this->model->findOrNew(0);
        Former::populate($web_alumnus);

        return view('alum::admin.web_alumnus.create', compact('web_alumnus'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(WebAlumnusAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $web_alumnus = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('alum::web_alumnus.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(WebAlumnusAdminRequest $request, $id)
    {
        $web_alumnus = $this->model->find($id);

        Former::populate($web_alumnus);

        return view('alum::admin.web_alumnus.edit', compact('web_alumnus'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(WebAlumnusAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $web_alumnus = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('alum::web_alumnus.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(WebAlumnusAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('alum::web_alumnus.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
